BETSE Developer's Tutorial
===========
BETSE is a self-contained software package, but it is also possible to use 
modules and methods from BETSE as tools in your own projects. The BETSE Developer's 
Tutorial is a Jupyter Notebook script that allows you to import BETSE modules, 
run a sim in the Jupyter Notebook, and gives some pointers on how to access
and plot simulation data and data structures of the BETSE sim. 

**How to Use the Developer's Tutorial Script**

To use these simulations, first install BETSE (if you haven't done so already):

https://gitlab.com/betse/betse#simple

Note that using Anaconda to install BETSE will also install [Jupyter Notebooks](https://jupyter.org/). 

Download the Developers Tutorial and unzip it into a 
directory of your choice on your computer (e.g. 'BETSE_Sims'):

[Developer's Tutorial](https://www.dropbox.com/s/f4ilizqnbmn2of5/developer.zip?dl=0)

Open the Jupyter Notebook 'Dev_Demo_BETSEv1.0.ipynb' and follow instructions 
therein. Features of the BETSE simulation that the Developer's Tutorial runs
can be edited by making changes to the 'sim_config.yaml' file included with 
the Developer's Tutorial package. 

